@@ -1,7 +1,7 @@
 import asyncio
 
-from const import MESSAGE_PROTOCOL, HEADER_PROTOCOL, DETAILLIST_PROTOCOL
-from utils import (
+from deepfos_ipc_protocol.const import MESSAGE_PROTOCOL, HEADER_PROTOCOL, DETAILLIST_PROTOCOL
+from deepfos_ipc_protocol.utils import (
     judge_data_format,
     to_msg_protocol,
     to_header_protocol,
