@@ -1,13 +1,13 @@
 import asyncio
 
 from inspect import isfunction
-from utils import (
+from deepfos_ipc_protocol.utils import (
     resolve_header_protocol,
     resolve_msg_protocol,
     resolve_detaillist_protocol,
     logging
 )
-from const import (
+from deepfos_ipc_protocol.const import (
     HEADER_PROTOCOL,
     MESSAGE_PROTOCOL,
     DETAILLIST_PROTOCOL
@@ -96,7 +96,3 @@ class EchoServer:
 
     def run(self):
         asyncio.run(self.task())
-        
-
-m = EchoServer("../unix_sock.sock")
-m.run()
\ No newline at end of file
