@@ -1,5 +1,5 @@
 from typing import Dict
-from const import (
+from deepfos_ipc_protocol.const import (
     HEADER_REVERSE_FIELD_MAP,
     SUBTASKUPDATE_META,
     SUBTASKUPDATE_FIELD_MAP,
